@@ -1,20 +1,17 @@
 '''
-@lanhuage: python
-@Descripttion:  https://blog.csdn.net/qq_33196814/article/details/99992771
-@version: beta
-@Author: xiaoshuyui
-@Date: 2020-04-22 17:07:28
+lanhuage: python
+Descripttion:  https://blog.csdn.net/qq_33196814/article/details/99992771
+version: beta
+Author: xiaoshuyui
+Date: 2020-04-22 17:07:28
 LastEditors: xiaoshuyui
-LastEditTime: 2020-10-10 15:45:56
+LastEditTime: 2021-02-19 16:50:40
 '''
-# import json
-import xmltodict
-import xml.etree.ElementTree as ET
-from xml.dom.minidom import parse, parseString
 import os
+import xml.etree.ElementTree as ET
+from xml.dom.minidom import parse
 
-# from lxml.etree import Element, SubElement, tostring
-# from xml.etree.ElementTree import fromstring, ElementTree
+import xmltodict
 
 
 def json_to_xml(json_str):
@@ -165,12 +162,9 @@ def img2xml_multiobj(tmpPath: str, aimPath: str, folder: str, filename: str,
 
     """
     annotation = {}
-    # annotation['folder'] = "HBXZ"
     annotation['folder'] = folder
     annotation['filename'] = filename
-    # annotation['filename'] = "xxx.jpg"
     annotation['path'] = path
-    # annotation['path'] = "xxxx\\xxxxx\\xxx.jpg"
 
     source = {}
     source['database'] = "Unknown"
@@ -179,8 +173,6 @@ def img2xml_multiobj(tmpPath: str, aimPath: str, folder: str, filename: str,
 
     size = {}
     size['width'] = width
-    # size['width'] = 903
-    # size['height'] = 1722
     size['height'] = height
     size['depth'] = 1
 
@@ -215,29 +207,5 @@ def img2xml_multiobj(tmpPath: str, aimPath: str, folder: str, filename: str,
         domTree = ET.parse(tmpPath)
         root = domTree.getroot()
         root = prettyXml(root, '\t', '\n')
-        # ET.dump(root)
         tree = ET.ElementTree(root)
         tree.write(tmpPath)
-        # with open(tmpPath, 'w') as f:
-        #     domTree.writexml(f, addindent='  ', encoding='utf-8')
-
-
-# if __name__ == "__main__":
-
-#     bndbox = {}
-#     # bndbox['xmin'] = 387
-#     # bndbox['ymin'] = 34
-#     # bndbox['xmax'] = 578
-#     # bndbox['ymax'] = 1622
-
-#     bndbox['xmin'] = 1
-#     bndbox['ymin'] = 2
-#     bndbox['xmax'] = 150
-#     bndbox['ymax'] = 150
-
-#     writeXML("D:\DefectDemo\DEMO2\defect\\224-F-76-6-0000.xml",'sadasd',bndbox)
-
-# with open("D:\\getWeld\\insertXML\\test2.xml",'rb') as f:
-# f = open("D:\\getWeld\\insertXML\\test2.xml",'w')
-# f.writelines(img2xml("HBXZ","aa","asas\\aa.xx",12,23,"aaa",123,444,4523,664))
-# f.close()
