@@ -5,16 +5,20 @@ version: beta
 Author: xiaoshuyui
 Date: 2020-08-19 11:27:38
 LastEditors: xiaoshuyui
-LastEditTime: 2020-10-21 19:29:59
+LastEditTime: 2021-02-19 16:48:43
 '''
 import json
+import os
+
+import numpy as np
 from convertmask.utils.img2xml.processor_multiObj import img2xml_multiobj
 from convertmask.utils.methods.logger import logger
-import os
-import numpy as np
 
 
 def j2xConvert(jsonFilePath: str):
+    """this function is used to convert jsons(labelme) to xmls(labelImg)
+
+    """
     with open(jsonFilePath, 'r', encoding='utf-8') as f:
         jsonObj = json.load(f)
         if isinstance(jsonObj, str):
