@@ -1,20 +1,22 @@
 '''
-@lanhuage: python
-@Descripttion: 
-@version: beta
-@Author: xiaoshuyui
-@Date: 2020-06-09 16:25:31
+lanhuage: python
+Descripttion: 
+version: beta
+Author: xiaoshuyui
+Date: 2020-06-09 16:25:31
 LastEditors: xiaoshuyui
-LastEditTime: 2020-10-10 15:47:13
+LastEditTime: 2021-02-19 16:44:38
 '''
 import base64
-import _io
-import numpy as np
+from convertmask import baseDecorate
 # import cv2
 import io
+
+import numpy as np
 import PIL
 
 
+@baseDecorate()
 def imgEncode(img_or_path):
     if isinstance(img_or_path, np.ndarray):
         """
@@ -35,7 +37,7 @@ def imgEncode(img_or_path):
     else:
         if isinstance(img_or_path, str):
             i = open(img_or_path, 'rb')
-        elif isinstance(img_or_path, _io.BufferedReader):
+        elif isinstance(img_or_path, io.BufferedReader):
             i = img_or_path
         else:
             raise TypeError('Input type error!')
