@@ -5,13 +5,12 @@ version: beta
 Author: xiaoshuyui
 Date: 2020-08-19 08:59:04
 LastEditors: xiaoshuyui
-LastEditTime: 2020-10-15 08:33:46
+LastEditTime: 2021-01-13 13:55:26
 '''
 import logging
 
 import termcolor
-
-from convertmask import __appname__
+from convertmask import __appname__,__current_platform__
 
 COLORS = {
     'WARNING': 'yellow',
@@ -30,15 +29,20 @@ class ColoredFormatter(logging.Formatter):
     def format(self, record):
         levelname = record.levelname
         if self.use_color and levelname in COLORS:
-            colored_levelname = termcolor.colored('[{}]'.format(levelname),
-                                                  color=COLORS[levelname])
+            if __current_platform__ != 'Windows':
+                colored_levelname = termcolor.colored('[{}]'.format(levelname),
+                                                      color=COLORS[levelname])
+            else:
+                colored_levelname = levelname
             record.levelname = colored_levelname
         return logging.Formatter.format(self, record)
 
 
 class ColoredLogger(logging.Logger):
-
-    fmt_filename = termcolor.colored('%(filename)s', attrs={'bold': True})
+    if __current_platform__ != "Windows":
+        fmt_filename = termcolor.colored('%(filename)s', attrs={'bold': True})
+    else:
+        fmt_filename = '%(filename)s'
     FORMAT = '%(levelname)s %(message)s ({}:%(lineno)d)'.format(fmt_filename)
 
     def __init__(self, name):
