@@ -4,8 +4,8 @@
 @version: beta
 @Author: xiaoshuyui
 @Date: 2020-06-10 09:20:18
-@LastEditors: xiaoshuyui
-@LastEditTime: 2020-06-10 09:22:20
+LastEditors: xiaoshuyui
+LastEditTime: 2021-01-04 13:56:17
 '''
 
 
@@ -17,7 +17,6 @@ def rm(filepath):
     d = ""
     for line in lines:
         c = line.replace('"group_id": "null",', '"group_id": null,')
-
         d += c
 
     p.seek(0)
