@@ -5,16 +5,35 @@ version: beta
 Author: xiaoshuyui
 Date: 2020-08-24 08:54:29
 LastEditors: xiaoshuyui
-LastEditTime: 2020-10-20 10:56:43
+LastEditTime: 2021-02-19 16:37:04
 '''
-import xml.etree.ElementTree as ET
-import os
-from convertmask.utils.methods.logger import logger
 import glob
+import os
+import xml.etree.ElementTree as ET
+
+from convertmask.utils.methods.logger import logger
 from tqdm import tqdm
 
 
 def x2yConvert(xmlpath, labelPath=''):
+    """ this function is used to convert xmls to yolo txts
+    
+    params:
+    xmlpath : xmls saved folder path
+    labelPath : can be blank, classes information,like
+             '''
+             
+             classname1
+
+             classname2
+
+             classname3
+             
+             ...
+
+             '''
+
+    """
     labels = readLabels(labelPath)
     parent_path = os.path.dirname(xmlpath)
     if not os.path.exists(xmlpath):
